JweHeaderSet

Struct JweHeaderSet 

pub struct JweHeaderSet { /* private fields */ }
Represent JWE protected and unprotected header claims

Implementations

Source

impl JweHeaderSet

pub fn new() -> Self

Return a JweHeader instance.

pub fn set_algorithm(&mut self, value: impl Into<String>, protection: bool)

Set a value for algorithm header claim (alg).

Arguments
  • value - a algorithm
  • protection - If it dosen’t need protection, set false.
pub fn algorithm(&self) -> Option<&str>

Return the value for algorithm header claim (alg).

pub fn set_content_encryption( &mut self, value: impl Into<String>, protection: bool, )

Set a value for content encryption header claim (enc).

Arguments
  • value - a content encryption
  • protection - If it dosen’t need protection, set false.
pub fn content_encryption(&self) -> Option<&str>

Return the value for content encryption header claim (enc).

pub fn set_compression(&mut self, value: impl Into<String>)

Set a value for compression header claim (zip).

Arguments
  • value - a encryption
pub fn compression(&self) -> Option<&str>

Return the value for compression header claim (zip).

pub fn set_jwk_set_url(&mut self, value: impl Into<String>, protection: bool)

Set a value for JWK set URL header claim (jku).

Arguments
  • value - a JWK set URL
pub fn jwk_set_url(&self) -> Option<&str>

Return the value for JWK set URL header claim (jku).

pub fn set_jwk(&mut self, value: Jwk, protection: bool)

Set a value for JWK header claim (jwk).

Arguments
  • value - a JWK
pub fn jwk(&self) -> Option<Jwk>

Return the value for JWK header claim (jwk).

pub fn set_x509_url(&mut self, value: impl Into<String>, protection: bool)

Set a value for X.509 URL header claim (x5u).

Arguments
  • value - a X.509 URL
pub fn x509_url(&self) -> Option<&str>

Return a value for a X.509 URL header claim (x5u).

pub fn set_x509_certificate_chain( &mut self, values: &Vec<impl AsRef<[u8]>>, protection: bool, )

Set values for X.509 certificate chain header claim (x5c).

Arguments
  • values - X.509 certificate chain
pub fn x509_certificate_chain(&self) -> Option<Vec<Vec<u8>>>

Return values for a X.509 certificate chain header claim (x5c).

pub fn set_x509_certificate_sha1_thumbprint( &mut self, value: impl AsRef<[u8]>, protection: bool, )

Set a value for X.509 certificate SHA-1 thumbprint header claim (x5t).

Arguments
  • value - A X.509 certificate SHA-1 thumbprint
pub fn x509_certificate_sha1_thumbprint(&self) -> Option<Vec<u8>>

Return the value for X.509 certificate SHA-1 thumbprint header claim (x5t).

pub fn set_x509_certificate_sha256_thumbprint( &mut self, value: impl AsRef<[u8]>, protection: bool, )

Set a value for a x509 certificate SHA-256 thumbprint header claim (x5t#S256).

Arguments
  • value - A x509 certificate SHA-256 thumbprint
pub fn x509_certificate_sha256_thumbprint(&self) -> Option<Vec<u8>>

Return the value for X.509 certificate SHA-256 thumbprint header claim (x5t#S256).

pub fn set_key_id(&mut self, value: impl Into<String>, protection: bool)

Set a value for key ID header claim (kid).

Arguments
  • value - a key ID
pub fn key_id(&self) -> Option<&str>

Return the value for key ID header claim (kid).

pub fn set_token_type(&mut self, value: impl Into<String>, protection: bool)

Set a value for token type header claim (typ).

Arguments
  • value - a token type (e.g. “JWT”)
pub fn token_type(&self) -> Option<&str>

Return the value for token type header claim (typ).

pub fn set_content_type(&mut self, value: impl Into<String>, protection: bool)

Set a value for content type header claim (cty).

Arguments
  • value - a content type (e.g. “JWT”)
pub fn content_type(&self) -> Option<&str>

Return the value for content type header claim (cty).

pub fn set_critical(&mut self, values: &Vec<impl AsRef<str>>)

Set values for critical header claim (crit).

Arguments
  • values - critical claim names
pub fn critical(&self) -> Option<Vec<&str>>

Return values for critical header claim (crit).

pub fn set_url(&mut self, value: impl Into<String>, protection: bool)

Set a value for url header claim (url).

Arguments
  • value - a url
pub fn url(&self) -> Option<&str>

Return the value for url header claim (url).

pub fn set_nonce(&mut self, value: impl AsRef<[u8]>, protection: bool)

Set a value for a nonce header claim (nonce).

Arguments
  • value - A nonce
pub fn nonce(&self) -> Option<Vec<u8>>

Return the value for nonce header claim (nonce).

pub fn set_agreement_partyuinfo( &mut self, value: impl AsRef<[u8]>, protection: bool, )

Set a value for a agreement PartyUInfo header claim (apu).

Arguments
  • value - A agreement PartyUInfo
pub fn agreement_partyuinfo(&self) -> Option<Vec<u8>>

Return the value for agreement PartyUInfo header claim (apu).

pub fn set_agreement_partyvinfo( &mut self, value: impl AsRef<[u8]>, protection: bool, )

Set a value for a agreement PartyVInfo header claim (apv).

Arguments
  • value - A agreement PartyVInfo
pub fn agreement_partyvinfo(&self) -> Option<Vec<u8>>

Return the value for agreement PartyVInfo header claim (apv).

pub fn set_issuer(&mut self, value: impl Into<String>, protection: bool)

Set a value for issuer header claim (iss).

Arguments
  • value - a issuer
pub fn issuer(&self) -> Option<&str>

Return the value for issuer header claim (iss).

pub fn set_subject(&mut self, value: impl Into<String>, protection: bool)

Set a value for subject header claim (sub).

Arguments
  • value - a subject
pub fn subject(&self) -> Option<&str>

Return the value for subject header claim (sub).

pub fn set_audience(&mut self, values: Vec<impl Into<String>>, protection: bool)

Set values for audience header claim (aud).

Arguments
  • values - a list of audiences
pub fn audience(&self) -> Option<Vec<&str>>

Return values for audience header claim (aud).

pub fn set_claim( &mut self, key: &str, value: Option<Value>, protection: bool, ) -> Result<(), JoseError>

pub fn claims_set(&self, protection: bool) -> &Map<String, Value>

Return values for header claims set

pub fn to_map(&self) -> Map<String, Value>