EddsaJwsAlgorithm

Enum EddsaJwsAlgorithm 

pub enum EddsaJwsAlgorithm {
    Eddsa,
}

Variants



Eddsa

EdDSA signature algorithms

Implementations

Source

impl EddsaJwsAlgorithm

pub fn generate_key_pair(&self, curve: EdCurve) -> Result<EdKeyPair, JoseError>

Generate a EdDSA key pair

Arguments
  • curve - EdDSA curve algorithm
pub fn key_pair_from_der( &self, input: impl AsRef<[u8]>, ) -> Result<EdKeyPair, JoseError>

Create a EdDSA key pair from a private key that is a DER encoded PKCS#8 PrivateKeyInfo.

Arguments
  • input - A private key that is a DER encoded PKCS#8 PrivateKeyInfo.
pub fn key_pair_from_pem( &self, input: impl AsRef<[u8]>, ) -> Result<EdKeyPair, JoseError>

Create a EdDSA key pair from a private key of common or traditinal PEM format.

Common PEM format is a DER and base64 encoded PKCS#8 PrivateKeyInfo that surrounded by “—–BEGIN/END PRIVATE KEY––”.

Traditional PEM format is a DER and base64 encoded PKCS#8 PrivateKeyInfo that surrounded by “—–BEGIN/END ED25519/ED448 PRIVATE KEY––”.

Arguments
  • input - A private key of common or traditinal PEM format.
pub fn signer_from_der( &self, input: impl AsRef<[u8]>, ) -> Result<EddsaJwsSigner, JoseError>

Return a signer from a private key that is a DER encoded PKCS#8 PrivateKeyInfo.

Arguments
  • input - A private key that is a DER encoded PKCS#8 PrivateKeyInfo.
pub fn signer_from_pem( &self, input: impl AsRef<[u8]>, ) -> Result<EddsaJwsSigner, JoseError>

Return a signer from a private key of common or traditinal PEM format.

Common PEM format is a DER and base64 encoded PKCS#8 PrivateKeyInfo that surrounded by “—–BEGIN/END PRIVATE KEY––”.

Traditional PEM format is a DER and base64 encoded PKCS#8 PrivateKeyInfo that surrounded by “—–BEGIN/END ED25519/ED448 PRIVATE KEY––”.

Arguments
  • input - A private key of common or traditinal PEM format.
pub fn signer_from_jwk(&self, jwk: &Jwk) -> Result<EddsaJwsSigner, JoseError>

Return a signer from a private key that is formatted by a JWK of OKP type.

Arguments
  • jwk - A private key that is formatted by a JWK of OKP type.
pub fn verifier_from_der( &self, input: impl AsRef<[u8]>, ) -> Result<EddsaJwsVerifier, JoseError>

Return a verifier from a public key that is a DER encoded SubjectPublicKeyInfo.

Arguments
  • input - A public key that is a DER encoded SubjectPublicKeyInfo.
pub fn verifier_from_pem( &self, input: impl AsRef<[u8]>, ) -> Result<EddsaJwsVerifier, JoseError>

Return a verifier from a key of common PEM format.

Common PEM format is a DER and base64 encoded SubjectPublicKeyInfo that surrounded by “—–BEGIN/END PUBLIC KEY––”.

Arguments
  • input - A key of common or traditional PEM format.
pub fn verifier_from_jwk( &self, jwk: &Jwk, ) -> Result<EddsaJwsVerifier, JoseError>

Return a verifier from a public key that is formatted by a JWK of OKP type.

Arguments
  • jwk - A public key that is formatted by a JWK of OKP type.