pub enum RsassaJwsAlgorithm {
Rs256,
Rs384,
Rs512,
}Variants
Rs256
RSASSA-PKCS1-v1_5 using SHA-256
Rs384
RSASSA-PKCS1-v1_5 using SHA-384
Rs512
RSASSA-PKCS1-v1_5 using SHA-512
Implementations
Sourceimpl RsassaJwsAlgorithm
impl RsassaJwsAlgorithm
Sourcepub fn generate_key_pair(&self, bits: u32) -> Result<RsaKeyPair, JoseError>
pub fn generate_key_pair(&self, bits: u32) -> Result<RsaKeyPair, JoseError>
Sourcepub fn key_pair_from_der(
&self,
input: impl AsRef<[u8]>,
) -> Result<RsaKeyPair, JoseError>
pub fn key_pair_from_der( &self, input: impl AsRef<[u8]>, ) -> Result<RsaKeyPair, JoseError>
Create a RSA key pair from a private key that is a DER encoded PKCS#8 PrivateKeyInfo or PKCS#1 RSAPrivateKey.
Arguments
input- A private key that is a DER encoded PKCS#8 PrivateKeyInfo or PKCS#1 RSAPrivateKey.
Sourcepub fn key_pair_from_pem(
&self,
input: impl AsRef<[u8]>,
) -> Result<RsaKeyPair, JoseError>
pub fn key_pair_from_pem( &self, input: impl AsRef<[u8]>, ) -> Result<RsaKeyPair, JoseError>
Create a RSA key pair from a private key of common or traditinal PEM format.
Common PEM format is a DER and base64 encoded PKCS#8 PrivateKeyInfo that surrounded by “—–BEGIN/END PRIVATE KEY––”.
Traditional PEM format is a DER and base64 encoded PKCS#1 RSAPrivateKey that surrounded by “—–BEGIN/END RSA PRIVATE KEY––”.
Arguments
input- A private key of common or traditinal PEM format.
Sourcepub fn signer_from_der(
&self,
input: impl AsRef<[u8]>,
) -> Result<RsassaJwsSigner, JoseError>
pub fn signer_from_der( &self, input: impl AsRef<[u8]>, ) -> Result<RsassaJwsSigner, JoseError>
Return a signer from a private key that is a DER encoded PKCS#8 PrivateKeyInfo or PKCS#1 RSAPrivateKey.
Arguments
input- A private key that is a DER encoded PKCS#8 PrivateKeyInfo or PKCS#1 RSAPrivateKey.
Sourcepub fn signer_from_pem(
&self,
input: impl AsRef<[u8]>,
) -> Result<RsassaJwsSigner, JoseError>
pub fn signer_from_pem( &self, input: impl AsRef<[u8]>, ) -> Result<RsassaJwsSigner, JoseError>
Return a signer from a private key of common or traditinal PEM format.
Common PEM format is a DER and base64 encoded PKCS#8 PrivateKeyInfo that surrounded by “—–BEGIN/END PRIVATE KEY––”.
Traditional PEM format is a DER and base64 encoded PKCS#1 RSAPrivateKey that surrounded by “—–BEGIN/END RSA PRIVATE KEY––”.
Arguments
input- A private key of common or traditinal PEM format.
Sourcepub fn signer_from_jwk(&self, jwk: &Jwk) -> Result<RsassaJwsSigner, JoseError>
pub fn signer_from_jwk(&self, jwk: &Jwk) -> Result<RsassaJwsSigner, JoseError>
Return a signer from a private key that is formatted by a JWK of RSA type.
Arguments
jwk- A private key that is formatted by a JWK of RSA type.
Sourcepub fn verifier_from_der(
&self,
input: impl AsRef<[u8]>,
) -> Result<RsassaJwsVerifier, JoseError>
pub fn verifier_from_der( &self, input: impl AsRef<[u8]>, ) -> Result<RsassaJwsVerifier, JoseError>
Return the verifier from a public key that is a DER encoded SubjectPublicKeyInfo or PKCS#1 RSAPublicKey.
Arguments
input- A public key that is a DER encoded SubjectPublicKeyInfo or PKCS#1 RSAPublicKey.
Sourcepub fn verifier_from_pem(
&self,
input: impl AsRef<[u8]>,
) -> Result<RsassaJwsVerifier, JoseError>
pub fn verifier_from_pem( &self, input: impl AsRef<[u8]>, ) -> Result<RsassaJwsVerifier, JoseError>
Return a verifier from a key of common or traditional PEM format.
Common PEM format is a DER and base64 encoded SubjectPublicKeyInfo that surrounded by “—–BEGIN/END PUBLIC KEY––”.
Traditional PEM format is a DER and base64 PKCS#1 RSAPublicKey that surrounded by “—–BEGIN/END RSA PUBLIC KEY––”.
Arguments
input- A public key of common or traditional PEM format.
Sourcepub fn verifier_from_jwk(
&self,
jwk: &Jwk,
) -> Result<RsassaJwsVerifier, JoseError>
pub fn verifier_from_jwk( &self, jwk: &Jwk, ) -> Result<RsassaJwsVerifier, JoseError>
Return a verifier from a public key that is formatted by a JWK of RSA type.
Arguments
jwk- A public key that is formatted by a JWK of RSA type.