JwsContext

Struct JwsContext 

pub struct JwsContext { /* private fields */ }

Implementations

Source

impl JwsContext

pub fn new() -> Self

pub fn is_acceptable_critical(&self, name: &str) -> bool

Test a critical header claim name is acceptable.

Arguments
  • name - a critical header claim name
pub fn add_acceptable_critical(&mut self, name: &str)

Add a acceptable critical header claim name

Arguments
  • name - a acceptable critical header claim name
pub fn remove_acceptable_critical(&mut self, name: &str)

Remove a acceptable critical header claim name

Arguments
  • name - a acceptable critical header claim name
pub fn serialize_compact( &self, payload: &[u8], header: &JwsHeader, signer: &dyn JwsSigner, ) -> Result<String, JoseError>

Return a representation of the data that is formatted by compact serialization.

Arguments
  • payload - The payload data.
  • header - The JWS heaser claims.
  • signer - The JWS signer.
pub fn serialize_compact_with_selector<'a, F>( &self, payload: &[u8], header: &JwsHeader, selector: F, ) -> Result<String, JoseError>
where F: Fn(&JwsHeader) -> Option<&'a dyn JwsSigner>,

Return a representation of the data that is formatted by compact serialization.

Arguments
  • payload - The payload data.
  • header - The JWS heaser claims.
  • selector - a function for selecting the signing algorithm.
pub fn serialize_general_json( &self, payload: &[u8], signers: &[(&JwsHeaderSet, &dyn JwsSigner)], ) -> Result<String, JoseError>

Return a representation of the data that is formatted by flattened json serialization.

Arguments
  • protected - The JWS protected header claims.
  • header - The JWS unprotected header claims.
  • payload - The payload data.
  • signers - The JWS signer.
pub fn serialize_general_json_with_selecter<'a, F>( &self, payload: &[u8], headers: &[&JwsHeaderSet], selector: F, ) -> Result<String, JoseError>
where F: Fn(usize, &JwsHeader) -> Option<&'a dyn JwsSigner>,

Return a representation of the data that is formatted by flattened json serialization.

Arguments
  • payload - The payload data.
  • headers - The JWS headers.
  • selector - a function for selecting the signing algorithm.
pub fn serialize_flattened_json( &self, payload: &[u8], header: &JwsHeaderSet, signer: &dyn JwsSigner, ) -> Result<String, JoseError>

Return a representation of the data that is formatted by flattened json serialization.

Arguments
  • payload - The payload data.
  • header - The JWS protected and unprotected header claims.
  • signer - The JWS signer.
pub fn serialize_flattened_json_with_selector<'a, F>( &self, payload: &[u8], header: &JwsHeaderSet, selector: F, ) -> Result<String, JoseError>
where F: Fn(&JwsHeader) -> Option<&'a dyn JwsSigner>,

Return a representation of the data that is formatted by flatted json serialization.

Arguments
  • payload - The payload data.
  • header - The JWS protected and unprotected header claims.
  • selector - a function for selecting the signing algorithm.
pub fn deserialize_compact( &self, input: impl AsRef<[u8]>, verifier: &dyn JwsVerifier, ) -> Result<(Vec<u8>, JwsHeader), JoseError>

Deserialize the input that is formatted by compact serialization.

Arguments
  • input - The input data.
  • header - The decoded JWS header claims.
  • verifier - The JWS verifier.
pub fn deserialize_compact_with_selector<'a, F>( &self, input: impl AsRef<[u8]>, selector: F, ) -> Result<(Vec<u8>, JwsHeader), JoseError>
where F: Fn(&JwsHeader) -> Result<Option<&'a dyn JwsVerifier>, JoseError>,

Deserialize the input that is formatted by compact serialization.

Arguments
  • input - The input data.
  • header - The decoded JWS header claims.
  • selector - a function for selecting the verifying algorithm.
pub fn deserialize_json<'a>( &self, input: impl AsRef<[u8]>, verifier: &'a dyn JwsVerifier, ) -> Result<(Vec<u8>, JwsHeader), JoseError>

Deserialize the input that is formatted by json serialization.

Arguments
  • input - The input data.
  • header - The decoded JWS header claims.
  • verifier - The JWS verifier.
pub fn deserialize_json_with_selector<'a, F>( &self, input: impl AsRef<[u8]>, selector: F, ) -> Result<(Vec<u8>, JwsHeader), JoseError>
where F: Fn(&JwsHeader) -> Result<Option<&'a dyn JwsVerifier>, JoseError>,

Deserialize the input that is formatted by json serialization.

Arguments
  • input - The input data.
  • header - The decoded JWS header claims.
  • selector - a function for selecting the verifying algorithm.