JwtPayloadValidator

Struct JwtPayloadValidator 

pub struct JwtPayloadValidator { /* private fields */ }
Represents JWT payload validator.

Implementations

Source

impl JwtPayloadValidator

pub fn new() -> Self

Return a new JwtPayloadValidator.

pub fn set_base_time(&mut self, base_time: SystemTime)

Set a base time for time related claims (exp, nbf) validation.

Arguments
  • base_time - a min time
pub fn base_time(&self) -> Option<&SystemTime>

Return the base time for time related claims (exp, nbf) validation.

pub fn set_min_issued_time(&mut self, min_issued_time: SystemTime)

Set a minimum time for issued at payload claim (iat) validation.

Arguments
  • min_issued_time - a minimum time at which the JWT was issued.
pub fn min_issued_time(&self) -> Option<&SystemTime>

Return the minimum time for issued at payload claim (iat).

pub fn set_max_issued_time(&mut self, max_issued_time: SystemTime)

Set a maximum time for issued at payload claim (iat) validation.

Arguments
  • max_issued_time - a maximum time at which the JWT was issued.
pub fn max_issued_time(&self) -> Option<&SystemTime>

Return the maximum time for issued at payload claim (iat).

pub fn set_issuer(&mut self, value: impl Into<String>)

Set a value for issuer payload claim (iss) validation.

Arguments
  • value - a issuer
pub fn issuer(&self) -> Option<&str>

Return the value for issuer payload claim (iss) validation.

pub fn set_subject(&mut self, value: impl Into<String>)

Set a value for subject payload claim (sub) validation.

Arguments
  • value - a subject
pub fn subject(&self) -> Option<&str>

Return the value for subject payload claim (sub) validation.

pub fn set_audience(&mut self, value: impl Into<String>)

Set a value for audience payload claim (aud) validation.

Arguments
  • value - a audience
pub fn audience(&self) -> Option<&str>

Return the value for audience payload claim (aud) validation.

pub fn set_jwt_id(&mut self, value: impl Into<String>)

Set a value for JWT ID payload claim (jti) validation.

Arguments
  • value - A JWT ID
pub fn jwt_id(&self) -> Option<&str>

Return the value for JWT ID payload claim (jti) validation.

pub fn set_claim(&mut self, key: &str, value: Value)

Set a value for payload claim of a specified key.

Arguments
  • key - a key name of payload claim
  • value - a typed value of payload claim
pub fn claim(&self, key: &str) -> Option<&Value>

Return the value for payload claim of a specified key.

Arguments
  • key - a key name of payload claim
pub fn validate(&self, payload: &JwtPayload) -> Result<(), JoseError>

Validate a decoded JWT payload.

Arguments
  • payload - a decoded JWT payload.